//
//  DTMFGeneratorSaveFile.m
//  SoundDial
//
//  Created by Benjamin Ragheb on Fri Dec 05 2003.
//  Copyright (c) 2008 Benjamin Ragheb. All rights reserved.
//

#import "DTMFGeneratorSaveFile.h"

@implementation DTMFGenerator (DTMFGeneratorSaveFile)

- (void)beginSaveSheetWithFile:(NSString *)proposedName modalForWindow:(NSWindow *)window
{
    NSSavePanel *savePanel = [NSSavePanel savePanel];

    [savePanel setRequiredFileType:@"aiff"];
    [savePanel setCanSelectHiddenExtension:YES];
    [savePanel setDelegate:self];
    [savePanel beginSheetForDirectory:nil file:proposedName
                       modalForWindow:window modalDelegate:self
                       didEndSelector:@selector(savePanelDidEnd:returnCode:contextInfo:)
                          contextInfo:[[self aiffData] retain]];
}

- (NSString *)panel:(id)sender userEnteredFilename:(NSString *)filename confirmed:(BOOL)okFlag
{
    if (okFlag) {
        if (![[NSFileManager defaultManager] isWritableFileAtPath:[sender directory]]) {
            NSAlert *alert = [[NSAlert alloc] init];
            [alert setAlertStyle:NSCriticalAlertStyle];
            [alert setMessageText:@"Cannot save to selected folder."];
            [alert setInformativeText:
                [NSString stringWithFormat:@"You do not have permission to save "
                    "files in the folder %@.  Please select another folder.",
                    [sender directory]]];
            [alert addButtonWithTitle:@"OK"];
            NSBeep();
            [alert runModal];
            [alert release];
            return nil;
        }
    }
    return filename;
}

- (void)savePanelDidEnd:(NSSavePanel *)savePanel returnCode:(int)returnCode contextInfo:(NSData *)aiffData
{
    if (returnCode == NSFileHandlingPanelOKButton) {
        if ([aiffData writeToFile:[savePanel filename] atomically:NO]) {
            if ([savePanel isExtensionHidden]) {
                [[NSFileManager defaultManager] changeFileAttributes:
                    [NSDictionary dictionaryWithObject:[NSNumber numberWithBool:YES] 
                                                forKey:NSFileExtensionHidden]
                                                              atPath:[savePanel filename]];
            }
        } else {
            NSAlert *alert = [[NSAlert alloc] init];
            [alert setAlertStyle:NSCriticalAlertStyle];
            [alert setMessageText:@"Could not save file."];
            [alert setInformativeText:(@"SoundDial was unable to write the dialing "
                                       @"tones sound file to disk.")];
            [alert addButtonWithTitle:@"OK"];
            NSBeep();
            [alert runModal];
            [alert release];
        }
    }
    [aiffData release];
}

@end
