//
//  SoundDialABPlugIn.m
//
//  Created by Benjamin Ragheb on Fri Nov 28 2003.
//  Copyright (c) 2008 Benjamin Ragheb. All rights reserved.
//

#import "SoundDialABPlugIn.h"
#import "DTMFGeneratorSaveFile.h"

@implementation SoundDialABPlugIn

- (id)init
{
    self = [super init];
    if (self) {
        dtmfGenerator = [[DTMFGenerator alloc] init];
        userDefaults = [[NSUserDefaults alloc] init];
        [userDefaults addSuiteNamed:@"com.benzado.SoundDial"];
        [[NSNotificationCenter defaultCenter] 
            addObserver:self selector:@selector(app)
                   name:NSApplicationWillBecomeActiveNotification object:nil];
        [self reloadUserDefaults];
    }
    return self;
}

- (void)dealloc
{
    [[NSNotificationCenter defaultCenter] removeObserver:self];
    [userDefaults release];
    [dtmfGenerator release];
    [super dealloc];
}

- (void)reloadUserDefaults
{
    double duration;
    
    [userDefaults synchronize];
    duration = [[userDefaults objectForKey:@"ToneDuration"] doubleValue];
    [dtmfGenerator setToneDuration:(duration / 1000.0)];
    duration = [[userDefaults objectForKey:@"GapDuration"] doubleValue];
    [dtmfGenerator setGapDuration:(duration / 1000.0)];
    duration = [[userDefaults objectForKey:@"PauseDuration"] doubleValue];
    [dtmfGenerator setPauseDuration:(duration / 1000.0)];
}

- (void)applicationWillBecomeActive:(NSNotification *)notification
{
    [self reloadUserDefaults];
}

// This action works with phone numbers.
- (NSString *)actionProperty
{
    return kABPhoneProperty;
}

// Localize!
- (NSString *)titleForPerson:(ABPerson *)person identifier:(NSString *)identifier
{
    if ([[NSApp currentEvent] modifierFlags] & NSShiftKeyMask) {
        return @"Save Tones with SoundDial...";
    } else {
        return @"Play Tones with SoundDial";
    }
}

NSString *MyABDisplayedNameForPerson(ABPerson *person)
{
    int personFlags, nameOrder;
    NSString *firstName, *lastName;
    
    personFlags = [[person valueForProperty:kABPersonFlags] intValue];
    if (personFlags & kABShowAsCompany) {
        return [person valueForProperty:kABOrganizationProperty];
    }
    nameOrder = personFlags & kABNameOrderingMask;
    if (nameOrder == 0) {
        nameOrder = [[ABAddressBook sharedAddressBook] defaultNameOrdering];
    }
    firstName = [person valueForProperty:kABFirstNameProperty];
    lastName = [person valueForProperty:kABLastNameProperty];
    if (nameOrder == kABFirstNameFirst) {
        return [NSString stringWithFormat:@"%@ %@", firstName, lastName];
    } else {
        return [NSString stringWithFormat:@"%@ %@", lastName, firstName];
    }
}


// This method is called when the user selects your action. As above, this method
// is passed information about the data item rolled over.
- (void)performActionForPerson:(ABPerson *)person identifier:(NSString *)identifier
{
    ABMultiValue* values;
    int index;
    NSString* value;

    values = [person valueForProperty:kABPhoneProperty];
    index = [values indexForIdentifier:identifier];
    value = [values valueAtIndex:index];

    [self reloadUserDefaults];
    [dtmfGenerator appendTonesForString:value];
    if ([[NSApp currentEvent] modifierFlags] & NSShiftKeyMask) {
        NSString *proposedName;

        proposedName = [NSString stringWithFormat:@"%@ - %@.aiff",
            MyABDisplayedNameForPerson(person),
            ABLocalizedPropertyOrLabel([values labelAtIndex:index])];
        [dtmfGenerator beginSaveSheetWithFile:proposedName
                               modalForWindow:[NSApp mainWindow]];
    } else {
        [[dtmfGenerator sound] play];
    }
    [dtmfGenerator clear];
}


- (BOOL)shouldEnableActionForPerson:(ABPerson *)person identifier:(NSString *)identifier
{
    return YES;
}

@end
